# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2020-04-16 14:38:22
@LastEditTime: 2021-08-05 10:15:32
@LastEditors: HuangJianYi
:Description: 基础路由
"""
# 框架引用
from seven_framework.web_tornado.monitor import MonitorHandler
from seven_cloudapp_frame.handlers.core import *
from seven_cloudapp_frame.handlers.server import *
from seven_cloudapp_frame.handlers.client import *

def seven_cloudapp_frame_route():
    return [
        (r"/monitor", MonitorHandler),
        (r"/", IndexHandler),
        #客户端
        (r"/client/address_list", address.AddressInfoListHandler),
        (r"/client/login", user.LoginHandler),
        (r"/client/authorize", user.AuthorizeHandler),
        (r"/client/apply_black_unbind", user.ApplyBlackUnbindHandler),
        (r"/client/user_asset_list", user.UserAssetListHandler),
        (r"/client/asset_log_list", user.AssetLogListHandler),
        (r"/client/theme_info", theme.ThemeInfoHandler),
        (r"/client/save_theme", theme.SaveThemeHandler),
        (r"/client/save_skin", theme.SaveSkinHandler),
        (r"/client/theme_info_list", theme.ThemeInfoListHandler),
        (r"/client/skin_info_list", theme.SkinInfoListHandler),
        (r"/client/ip_info_list", ip.IpInfoListHandler),
        (r"/client/act_info", act.ActInfoHandler),
        (r"/client/app_expire", app.AppExpireHandler),
        (r"/client/submit_sku", goods.SubmitSkuHandler),
        (r"/client/sku_info", goods.SkuInfoHandler),
        (r"/client/goods_list", goods.GoodsListHandler),

        #千牛端
        (r"/server/saas_custom", base_s.SaasCustomHandler),
        (r"/server/login", user_s.LoginHandler),
        (r"/server/get_app_id", base_s.GetAppIDHandler),
        (r"/server/base_info", base_s.BaseInfoHandler),
        (r"/server/send_sms", base_s.SendSmsHandler),
        (r"/server/app_info", app_s.AppInfoHandler),
        (r"/server/instantiate", app_s.InstantiateAppHandler),
        (r"/server/version_upgrade", app_s.VersionUpgradeHandler),
        (r"/server/update_telephone", app_s.UpdateTelephoneHandler),
        (r"/server/act_type_list", act_s.ActTypeListHandler),
        (r"/server/next_progress", act_s.NextProgressHandler),
        (r"/server/add_act_info", act_s.AddActInfoHandler),
        (r"/server/update_act_info", act_s.UpdateActInfoHandler),
        (r"/server/act_info_list", act_s.ActInfoListHandler),
        (r"/server/act_info", act_s.ActInfoHandler),
        (r"/server/delete_act_info", act_s.DeleteActInfoHandler),
        (r"/server/review_act_info", act_s.ReviewActInfoHandler),
        (r"/server/release_act_info", act_s.ReleaseActInfoHandler),
        (r"/server/create_act_qrcode", act_s.CreateActQrCodeHandler),
        (r"/server/save_act_module", module_s.SaveActModuleHandler),
        (r"/server/act_module_list", module_s.ActModuleListHandler),
        (r"/server/delete_act_module", module_s.DeleteActModuleHandler),
        (r"/server/review_act_module", module_s.ReviewActModuleHandler),
        (r"/server/release_act_module", module_s.ReleaseActModuleHandler),
        (r"/server/save_act_prize", prize_s.SaveActPrizeHandler),
        (r"/server/act_prize_list", prize_s.ActPrizeListHandler),
        (r"/server/delete_act_prize", prize_s.DeleteActPrizeHandler),
        (r"/server/review_act_prize", prize_s.ReviewActPrizeHandler),
        (r"/server/release_act_prize", prize_s.ReleaseActPrizeHandler),
        (r"/server/stat_report_list", report_s.StatReportListHandler),
        (r"/server/trend_report_list", report_s.TrendReportListHandler),
        (r"/server/update_user_status", user_s.UpdateUserStatusHandler),
        (r"/server/update_user_status_by_black", user_s.UpdateUserStatusByBlackHandler),
        (r"/server/audit_user_black", user_s.AuditUserBlackHandler),
        (r"/server/user_black_list", user_s.UserBlackListHandler),
        (r"/server/update_user_asset", user_s.UpdateUserAssetHandler),
        (r"/server/asset_log_list", user_s.AssetLogListHandler),
        (r"/server/init_launch_goods", launch_s.InitLaunchGoodsHandler),
        (r"/server/async_launch_goods", launch_s.AsyncLaunchGoodsHandler),
        (r"/server/launch_goods_list", launch_s.LaunchGoodsListHandler),
        (r"/server/update_launch_goods_status", launch_s.UpdateLaunchGoodsStatusHandler),
        (r"/server/init_launch_goods_callback", launch_s.InitLaunchGoodsCallBackHandler),
        (r"/server/update_theme", theme_s.UpdateThemeHandler),
        (r"/server/theme_info_list", theme_s.ThemeInfoListHandler),
        (r"/server/skin_info_list", theme_s.SkinInfoListHandler),
        (r"/server/save_ip_info", ip_s.SaveIpInfoHandler),
        (r"/server/delete_ip_info", ip_s.DeleteIpInfoHandler),
        (r"/server/ip_info_list", ip_s.IpInfoListHandler),
        (r"/server/release_ip_info", ip_s.ReleaseIpInfoHandler),
        (r"/server/save_price_gear", price_s.SavePriceGearHandler),
        (r"/server/price_gear_list", price_s.PriceGearListHandler),
        (r"/server/delete_price_gear", price_s.DeletePriceGearHandler),
        (r"/server/review_price_gear", price_s.ReviewPriceGearHandler),
        (r"/server/check_price_gear", price_s.CheckPriceGearHandler),
        (r"/server/goods_list", goods_s.GoodsListHandler),
        (r"/server/goods_list_by_goodsids", goods_s.GoodsListByGoodsIDHandler),
        (r"/server/goods_info", goods_s.GoodsInfoHandler),
        (r"/server/benefit_detail", goods_s.BenefitDetailHandler),
    ]


#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class PriceGearModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(PriceGearModel, self).__init__(PriceGear, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class PriceGear:

    def __init__(self):
        super(PriceGear, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.relation_type = 0  # 关联类型：1商品skuid关联2商品id关联
        self.goods_id = 0  # 商品ID
        self.sku_id = ""  # sku_id
        self.price_gear_name = ""  # 档位名称
        self.price_gear_pic = ""  # 档位图片
        self.price = 0  # 价格
        self.is_del = 0  # 是否删除（1是0否）
        self.effective_date = "1900-01-01 00:00:00"  # 有效时间
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间
        self.remark = ""  # 备注

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'relation_type', 'goods_id', 'sku_id', 'price_gear_name', 'price_gear_pic', 'price', 'is_del', 'effective_date', 'create_date', 'modify_date', 'remark']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "price_gear_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-30 15:46:34
@LastEditTime: 2021-08-04 11:59:55
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.handlers.frame_base import *
from seven_cloudapp_frame.models.act_base_model import *
from seven_cloudapp_frame.models.top_base_model import *
from seven_cloudapp_frame.models.launch_base_model import *
from seven_cloudapp_frame.models.seven_model import *
from seven_cloudapp_frame.models.db_models.act.act_info_model import *
from seven_cloudapp_frame.models.db_models.act.act_prize_model import *
from seven_cloudapp_frame.models.db_models.launch.launch_goods_model import *
from seven_cloudapp_frame.models.db_models.price.price_gear_model import *


class InitLaunchGoodsHandler(TaoBaseHandler):
    """
    :description: 初始化商品投放
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 初始化商品投放
        :param act_id：活动标识
        :param module_id：活动模块标识
        :param source_types：商品来源，指定哪些位置的商品要进行投放（1活动奖品商品2价格档位商品） 多个逗号,分隔
        :return
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = int(self.get_param("act_id", 0))
        module_id = int(self.get_param("module_id", 0))
        source_types = self.get_param("source_types","1,2")

        online_url = self.get_online_url(act_id, app_id, module_id)
        launch_base_model = LaunchBaseModel(context=self)
        invoke_result_data = launch_base_model.init_launch_goods(app_id, act_id, source_types, online_url)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success(invoke_result_data.data)

class InitLaunchGoodsCallBackHandler(TaoBaseHandler):
    """
    :description: 初始化投放商品回调接口
    """
    def get_async(self):
        """
        :description: 初始化投放商品回调接口
        :param act_id：活动标识
        :param close_goods_id：投放失败时关闭投放的商品ID  多个逗号,分隔
        :return 
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))
        close_goods_id = self.get_param("close_goods_id")

        ActInfoModel(context=self).update_table("is_launch=1", "id=%s", params=act_id)
        if close_goods_id != "":
            LaunchGoodsModel(context=self).update_table("is_launch=0,launch_date=%s", "act_id=%s and goods_id in (" + close_goods_id + ")", params=[SevenHelper.get_now_datetime(),act_id])

        self.response_json_success()

class UpdateLaunchGoodsStatusHandler(TaoBaseHandler):
    """
    :description: 更改投放商品的状态
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 保存更改投放商品的状态
        :param act_id：活动id
        :param update_goods_id：更新商品ID（例：1）
        :return 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = int(self.get_param("act_id", 0))
        goods_id = int(self.get_param("update_goods_id", 0))
        if goods_id > 0:
            LaunchGoodsModel(context=self).update_table("is_launch=abs(is_launch-1),is_sync=0,launch_date=%s", "app_id=%s and act_id=%s and goods_id=%s", [self.get_now_datetime(), app_id, act_id, goods_id])

        self.response_json_success()

class LaunchGoodsListHandler(TaoBaseHandler):
    """
    :description: 投放商品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 投放商品列表
        :param act_id：活动id
        :param page_index：页索引
        :param page_size：页大小
        :return 列表
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = int(self.get_param("act_id", 0))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        launch_base_model = LaunchBaseModel(context=self)
        invoke_result_data = launch_base_model.launch_goods_list(app_id, act_id, page_size, page_index)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success(invoke_result_data.data)

class AsyncLaunchGoodsHandler(TaoBaseHandler):
    """
    :description: 同步投放商品（小程序投放-商品绑定/解绑）
    """
    @filter_check_params("app_id,act_id")
    def get_async(self):
        """
        :description: 同步投放商品（小程序投放-商品绑定/解绑）
        :param act_id：活动标识
        :param module_id：活动模块标识
        :return 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = int(self.get_param("act_id", 0))
        module_id = int(self.get_param("module_id", 0))

        online_url = self.get_online_url(act_id, app_id, module_id)
        launch_base_model = LaunchBaseModel(context=self)
        invoke_result_data = launch_base_model.async_launch_goods(app_id, act_id, online_url)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success()